@@ -4,7 +4,6 @@ import (
 	"bufio"
 	"errors"
 	"fmt"
-	"golang.org/x/crypto/ssh"
 	"math"
 	"os"
 	"os/signal"
@@ -13,6 +12,8 @@ import (
 	"strings"
 	"sync"
 
+	"golang.org/x/crypto/ssh"
+
 	"github.com/jedib0t/go-pretty/v6/text"
 
 	"github.com/alajmo/sake/core"
@@ -97,7 +98,7 @@ func (run *Run) RunTask(
 			return err
 		}
 
-		return &core.ExecError{Err: errors.New("Parse Error"), ExitCode: 4}
+		return &core.ExecError{Err: errors.New("parse Error"), ExitCode: 4}
 	}
 
 	// Remote + Local clients
@@ -266,7 +267,7 @@ func (run *Run) SetClients(
 	clientCh chan Client,
 	errCh chan ErrConnect,
 ) ([]ErrConnect, error) {
-	createLocalClient := func(strategy string, numTasks int, server dao.Server, wg *sync.WaitGroup, mu *sync.Mutex) {
+	createLocalClient := func(strategy string, numTasks int, server dao.Server, wg *sync.WaitGroup) {
 		defer wg.Done()
 
 		local := &LocalhostClient{
@@ -313,22 +314,37 @@ func (run *Run) SetClients(
 			remote.Sessions = append(remote.Sessions, SSHSession{})
 		}
 
-		var bastion *SSHClient
-		if server.BastionHost != "" {
-			bastion = &SSHClient{
-				Name:       "Bastion",
-				Host:       server.BastionHost,
-				User:       server.BastionUser,
-				Port:       server.BastionPort,
-				AuthMethod: authMethod,
-			}
-			// Connect to bastion
-			if err := bastion.Connect(ssh.Dial, run.Config.DisableVerifyHost, run.Config.KnownHostsFile, run.Config.DefaultTimeout, mu); err != nil {
-				errCh <- *err
-				return
-			}
+		if len(server.Bastions) > 0 {
+			var bastion *SSHClient
+			for _, bastionServer := range server.Bastions {
+				if bastion == nil {
+					bastion = &SSHClient{
+						Name:       "Bastion",
+						Host:       bastionServer.Host,
+						User:       bastionServer.User,
+						Port:       bastionServer.Port,
+						AuthMethod: authMethod,
+					}
+					if err := bastion.Connect(ssh.Dial, run.Config.DisableVerifyHost, run.Config.KnownHostsFile, run.Config.DefaultTimeout, mu); err != nil {
+						errCh <- *err
+						return
+					}
+				} else {
+					bastt := &SSHClient{
+						Name:       "Bastion",
+						Host:       bastionServer.Host,
+						User:       bastionServer.User,
+						Port:       bastionServer.Port,
+						AuthMethod: authMethod,
+					}
 
-			// Connect to server through bastion
+					if err := bastt.Connect(bastion.DialThrough, run.Config.DisableVerifyHost, run.Config.KnownHostsFile, run.Config.DefaultTimeout, mu); err != nil {
+						errCh <- *err
+						return
+					}
+					bastion = bastt
+				}
+			}
 			if err := remote.Connect(bastion.DialThrough, run.Config.DisableVerifyHost, run.Config.KnownHostsFile, run.Config.DefaultTimeout, mu); err != nil {
 				errCh <- *err
 				return
@@ -374,7 +390,7 @@ func (run *Run) SetClients(
 	// TODO: Dont create remote clients if task is set to local
 	for _, server := range run.Servers {
 		wg.Add(1)
-		go createLocalClient(task.Spec.Strategy, len(task.Tasks), server, &wg, &mu)
+		go createLocalClient(task.Spec.Strategy, len(task.Tasks), server, &wg)
 		if !server.Local {
 			wg.Add(1)
 			authMethods := getAuthMethod(server, &signers)
@@ -494,16 +510,19 @@ func ParseServers(
 	var errConnects []ErrConnect
 	for i := range *servers {
 		serv := cfg[(*servers)[i].Host]
-
-		// Bastion resolve:
+		// Bastion resolve, for instance, host: server-1 has an entry in ssh config
+		// that has ProxyJump, ProxyJump alias or if in sake it has a bastion: server-1
 		//  1. proxyjump alias
 		//	2. proxyjump
-		//	3. bastion alias
-		if proxyJump := serv.ProxyJump; proxyJump != "" {
+		//	3. bastion alias, in this case we need to handle multiple bastions
+		// In-case sake has bastions defined, then skip resolving
+		// TODO: Refactor this part
+		if proxyJump := serv.ProxyJump; proxyJump != "" && len((*servers)[i].Bastions) == 0 {
 			if hostName := cfg[proxyJump].HostName; hostName != "" {
 				// 1. proxyjump alias
-				(*servers)[i].BastionHost = hostName
-
+				bastionHost := hostName
+				bastionPort := (*servers)[i].Port
+				bastionUser := (*servers)[i].User
 				port := cfg[proxyJump].Port
 				if port != "" {
 					p, err := strconv.ParseUint(port, 10, 16)
@@ -518,64 +537,76 @@ func ParseServers(
 						errConnects = append(errConnects, *errConnect)
 						continue
 					}
-					(*servers)[i].BastionPort = uint16(p)
-				} else {
-					(*servers)[i].BastionPort = (*servers)[i].Port
+					bastionPort = uint16(p)
 				}
 
 				user := cfg[proxyJump].User
 				if user != "" {
-					(*servers)[i].BastionUser = user
-				} else {
-					(*servers)[i].BastionUser = (*servers)[i].User
+					bastionUser = user
 				}
+
+				bastion := dao.Bastion{
+					Host: bastionHost,
+					User: bastionUser,
+					Port: bastionPort,
+				}
+
+				(*servers)[i].Bastions = append((*servers)[i].Bastions, bastion)
 			} else {
 				// 2. proxyjump
-				user, host, port, err := core.ParseHostName(proxyJump, (*servers)[i].User, (*servers)[i].Port)
-				if err != nil {
-					errConnect := &ErrConnect{
-						Name:   (*servers)[i].Name,
-						User:   (*servers)[i].User,
-						Host:   (*servers)[i].Host,
-						Port:   (*servers)[i].Port,
-						Reason: err.Error(),
-					}
-					errConnects = append(errConnects, *errConnect)
-					continue
-				}
 
-				(*servers)[i].BastionHost = host
-				(*servers)[i].BastionPort = port
-				(*servers)[i].BastionUser = user
+				for _, proxy := range strings.Split(proxyJump, ",") {
+					user, host, port, err := core.ParseHostName(proxy, (*servers)[i].User, (*servers)[i].Port)
+					if err != nil {
+						errConnect := &ErrConnect{
+							Name:   (*servers)[i].Name,
+							User:   (*servers)[i].User,
+							Host:   (*servers)[i].Host,
+							Port:   (*servers)[i].Port,
+							Reason: err.Error(),
+						}
+						errConnects = append(errConnects, *errConnect)
+						continue
+					}
+
+					bastion := dao.Bastion{
+						Host: host,
+						User: user,
+						Port: port,
+					}
+					(*servers)[i].Bastions = append((*servers)[i].Bastions, bastion)
+				}
 			}
-		} else if bastionHost := cfg[(*servers)[i].BastionHost].HostName; bastionHost != "" {
+		} else {
 			// 3. bastion alias
-			(*servers)[i].BastionHost = bastionHost
-
-			port := cfg[(*servers)[i].BastionHost].Port
-			if port != "" {
-				p, err := strconv.ParseUint(port, 10, 16)
-				if err != nil {
-					errConnect := &ErrConnect{
-						Name:   (*servers)[i].Name,
-						User:   (*servers)[i].User,
-						Host:   (*servers)[i].Host,
-						Port:   (*servers)[i].Port,
-						Reason: err.Error(),
+			for j, bastion := range (*servers)[i].Bastions {
+				if bastionHost := cfg[bastion.Host].HostName; bastionHost != "" {
+					bastionPort := (*servers)[i].Port
+					bastionUser := (*servers)[i].User
+					if cfg[bastion.Host].Port != "" {
+						p, err := strconv.ParseUint(cfg[bastion.Host].Port, 10, 16)
+						if err != nil {
+							errConnect := &ErrConnect{
+								Name:   (*servers)[i].Name,
+								User:   (*servers)[i].User,
+								Host:   (*servers)[i].Host,
+								Port:   (*servers)[i].Port,
+								Reason: err.Error(),
+							}
+							errConnects = append(errConnects, *errConnect)
+							continue
+						}
+						bastionPort = uint16(p)
 					}
-					errConnects = append(errConnects, *errConnect)
-					continue
-				}
-				(*servers)[i].BastionPort = uint16(p)
-			} else {
-				(*servers)[i].BastionPort = (*servers)[i].Port
-			}
 
-			user := cfg[(*servers)[i].BastionHost].User
-			if user != "" {
-				(*servers)[i].BastionUser = user
-			} else {
-				(*servers)[i].BastionUser = (*servers)[i].User
+					if cfg[bastion.Host].User != "" {
+						bastionUser = cfg[bastion.Host].User
+					}
+
+					(*servers)[i].Bastions[j].Host = bastionHost
+					(*servers)[i].Bastions[j].User = bastionUser
+					(*servers)[i].Bastions[j].Port = bastionPort
+				}
 			}
 		}
 
@@ -856,12 +887,12 @@ func getWorkDir(
 	cmdDir string,
 	serverDir string,
 ) string {
-	cmdWDTrue := false
+	var cmdWDTrue bool
 	if cmdWD != "" {
 		cmdWDTrue = true
 	}
 
-	serverWDTrue := false
+	var serverWDTrue bool
 	if serverWD != "" {
 		serverWDTrue = true
 	}
